@@ -26,5 +26,4 @@ function ( geno , marker.label=NULL ,  miss.val=NA )  {
   colnames(code) <- marker.label
   rownames (code) <- rownames(geno)
   return ( code )
-} ### end of allele2toR
-
+}
